#
# spec file for package python-h11
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-h11
Version:        0.9.0
Release:        lp152.2.1
Summary:        A pure-Python, bring-your-own-I/O implementation of HTTP/11
License:        MIT
URL:            https://github.com/python-hyper/h11
Source:         https://files.pythonhosted.org/packages/source/h/h11/h11-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This is a little HTTP/1.1 library written from scratch in Python,
heavily inspired by hyper-h2 <https://hyper-h2.readthedocs.io>

%prep
%setup -q -n h11-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/*

%changelog
* Wed May  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not restrict pytest anymore, seems working
* Thu Aug 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.9.0:
  * no changelog
- Restrict pytest5 for now
* Wed Jun  5 2019 Petr Gajdos <pgajdos@suse.com>
- test package in %%check
* Tue Dec  4 2018 aloisio@gmx.com
- Update to version 0.8.1
  Bug fixes:
  * Always return headers as ``bytes`` objects (`#60
    <https://github.com/python-hyper/h11/issues/60>`__)
  Other changes:
  * Added proper license notices to the Javascript used in our
    documentation (`#61
    <https://github.com/python-hyper/h11/issues/60>`__)
  version 0.8.0
  Backwards **in**\compatible changes:
  * h11 now performs stricter validation on outgoing header
    names and header values: illegal characters are now rejected
    (example: you can't put a newline into an HTTP header), and
    header values with leading/trailing whitespace are also
    rejected (previously h11 would silently discard the
    whitespace). All these checks were already performed on
    incoming headers; this just extends that to outgoing
    headers.
  New features:
  * New method :meth:`Connection.send_failed`, to notify a
    :class:`Connection` object when data returned from
    :meth:`Connection.send` was *not* sent.
  Bug fixes:
  * Make sure that when computing the framing headers for HEAD
    responses, we produce the same results as we would for the
    corresponding GET.
  * Error out if a request has multiple Host: headers.
  * Send the Host: header first, as recommended by RFC 7230.
  * The Expect: header `is case-insensitive
    <https://tools.ietf.org/html/rfc7231#section-5.1.1>`__, so
    use case-insensitive matching when looking for 100-continue.
  Other changes:
  * Better error messages in several cases.
  * Provide correct ``error_status_hint`` in exception raised
    when encountering an invalid ``Transfer-Encoding`` header.
  * For better compatibility with broken servers, h11 now
    tolerates responses where the reason phrase is missing (not
    just empty).
  * Various optimizations and documentation improvements.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Feb 25 2018 aloisio@gmx.com
- Initial package (version 0.7.0)
